﻿Friend Class ViewModel : Implements ComponentModel.INotifyPropertyChanged

	Private WithEvents Game As Game = Nothing
	Private ReadOnly GameFileContentManager As New GameFileContentManager("Ergebnisse.txt")
	Public Event PropertyChanged As System.ComponentModel.PropertyChangedEventHandler Implements ComponentModel.INotifyPropertyChanged.PropertyChanged

	Private _PlayerVictoryCount As Integer
	Public Property PlayerVictoryCount As Integer
		Get
			Return _PlayerVictoryCount
		End Get
		Private Set
			_PlayerVictoryCount = Value
			RaisePropertyChange(NameOf(PlayerVictoryCount))
		End Set
	End Property

	Private _ComputerVictoryCount As Integer
	Public Property ComputerVictoryCount As Integer
		Get
			Return _ComputerVictoryCount
		End Get
		Private Set
			_ComputerVictoryCount = Value
			RaisePropertyChange(NameOf(ComputerVictoryCount))
		End Set
	End Property

	Private _DrawCount As Integer
	Public Property DrawCount As Integer
		Get
			Return _DrawCount
		End Get
		Private Set
			_DrawCount = Value
			RaisePropertyChange(NameOf(DrawCount))
		End Set
	End Property

	Private _CurrentPlayerResult As Integer
	Public Property CurrentPlayerResult As Integer
		Get
			Return _CurrentPlayerResult
		End Get
		Private Set
			_CurrentPlayerResult = Value
			RaisePropertyChange(NameOf(CurrentPlayerResult))
		End Set
	End Property

	Private _CurrentComputerResult As Integer
	Public Property CurrentComputerResult As Integer
		Get
			Return _CurrentComputerResult
		End Get
		Private Set
			_CurrentComputerResult = Value
			RaisePropertyChange(NameOf(CurrentComputerResult))
		End Set
	End Property

	Private _Result As String
	Public Property Result As String
		Get
			Return _Result
		End Get
		Private Set
			_Result = Value
			RaisePropertyChange(NameOf(Result))
		End Set
	End Property

	Private Sub RaisePropertyChange(<Runtime.CompilerServices.CallerMemberName> PropertyName As String)
		RaiseEvent PropertyChanged(Me, New System.ComponentModel.PropertyChangedEventArgs(PropertyName))
	End Sub

	Public Sub StartGame()
		ImportData()
		ShowCurrentGameStatistics()
	End Sub

	Private Sub ImportData()
		Dim CurrentGameStatistics = GameFileContentManager.GetGameStatisticsFromFile()
		Game = New Game(CurrentGameStatistics)
	End Sub

	Public Sub ThrowDice()
		Game.ThrowDice()
	End Sub

	Public Sub SaveStatistic()
		GameFileContentManager.WriteGameStatisticsToFile((Game.PlayerVictoryCount, Game.ComputerVictoryCount, Game.DrawCount))
	End Sub

	Private Sub Game_DiceThrow(sender As Object, e As DiceThrowingEventArgs) Handles Game.DiceThrow
		ShowResults(e)
		ShowCurrentGameStatistics()
	End Sub

	Private Sub ShowCurrentGameStatistics()
		PlayerVictoryCount = Game.PlayerVictoryCount
		ComputerVictoryCount = Game.ComputerVictoryCount
		DrawCount = Game.DrawCount
	End Sub

	Private Sub ShowResults(e As DiceThrowingEventArgs)
		CurrentPlayerResult = e.PlayerResult
		CurrentComputerResult = e.ComputerResult
		Select Case e.Result
			Case ThrowResult.PlayerWon : Result = "menno …"
			Case ThrowResult.ComputerWon : Result = "SIEG!"
			Case ThrowResult.Draw : Result = "langweilig"
		End Select
	End Sub

End Class