﻿Friend Class ViewModel

	Private WithEvents FrmMain As New FrmMain
	Private WithEvents Game As Game = Nothing
	Private ReadOnly GameFileContentManager As New GameFileContentManager("Ergebnisse.txt")

	Public Sub StartGame()
		ImportData()
		WireEvents()
		ShowCurrentGameStatistics()
		ShowGameForm()
		CutEventWires()
	End Sub

	Private Sub WireEvents()
		AddHandler FrmMain.BtnThrowDice.Click, AddressOf ThrowDice
		AddHandler FrmMain.BtnSaveAndExit.Click, AddressOf EndGame
	End Sub

	Private Sub CutEventWires()
		RemoveHandler FrmMain.BtnThrowDice.Click, AddressOf ThrowDice
		RemoveHandler FrmMain.BtnSaveAndExit.Click, AddressOf EndGame
	End Sub

	Private Sub ShowGameForm()
		FrmMain.ShowDialog()
	End Sub

	Private Sub ImportData()
		Dim CurrentGameStatistics = GameFileContentManager.GetGameStatisticsFromFile()
		Game = New Game(CurrentGameStatistics)
	End Sub

	Public Sub ThrowDice(sender As Object, e As EventArgs)
		Game.ThrowDice()
	End Sub

	Private Sub EndGame(sender As Object, e As EventArgs)
		SaveStatistic()
		CloseForm()
	End Sub

	Private Sub CloseForm()
		FrmMain.Close()
	End Sub

	Public Sub SaveStatistic()
		GameFileContentManager.WriteGameStatisticsToFile((Game.PlayerVictoryCount, Game.ComputerVictoryCount, Game.DrawCount))
	End Sub

	Private Sub Game_DiceThrow(sender As Object, e As DiceThrowingEventArgs) Handles Game.DiceThrow
		ShowResults(e)
		ShowCurrentGameStatistics()
	End Sub

	Private Sub ShowCurrentGameStatistics()
		FrmMain.LblPlayerVictoryCount.Text = Game.PlayerVictoryCount.ToString
		FrmMain.LblComputerVictoryCount.Text = Game.ComputerVictoryCount.ToString
		FrmMain.LblDrawCount.Text = Game.DrawCount.ToString
	End Sub

	Private Sub ShowResults(e As DiceThrowingEventArgs)
		FrmMain.LblCurrentPlayerResult.Text = e.PlayerResult.ToString
		FrmMain.LblCurrentComputerResult.Text = e.ComputerResult.ToString
		Select Case e.Result
			Case ThrowResult.PlayerWon : FrmMain.LblResult.Text = "menno …"
			Case ThrowResult.ComputerWon : FrmMain.LblResult.Text = "SIEG!"
			Case ThrowResult.Draw : FrmMain.LblResult.Text = "langweilig"
		End Select
	End Sub

End Class